@@ -35,6 +35,7 @@
 #include "g_options.h"
 #include "g_main.h"
 #include "g_scope.h"
+#include "g_file_dialogs.h"
 #include "util.h"
 #include "fft.h"
 #include "avg.h"
@@ -90,7 +91,6 @@ static gdouble da_to_act_y(gint y);
 static gboolean drawing_area_motion_event(GtkWidget * widget, GdkEventMotion * event, gpointer data);
 static void selection_event(GtkWidget * widget, GdkEventMotion * event, gpointer data);
 static gboolean drawing_area_button_press_event(GtkWidget * widget, GdkEventButton * event);
-static void open_file_dialog(GtkWidget * widget, gpointer data);
 static void select_soundcard_source(GtkWidget * widget, gpointer data);
 static void select_mode(GtkWidget * widget, gpointer data);
 static void save_full_pixmap(GtkWidget * widget, gpointer data);
@@ -163,6 +163,7 @@ static void get_main_menu(GtkWidget * window, GtkWidget ** menu_bar)
     *menu_bar = gtk_item_factory_get_widget(item_factory, "<main>");
 }
 
+
 static gint update_avgmax(gpointer data)	
 {
   GtkWidget *label;
@@ -184,6 +185,7 @@ static gint update_avgmax(gpointer data)
   return TRUE;
 }
 
+
 static gint update_avgvar(gpointer data)	
 {
   GtkWidget *label;
@@ -203,6 +205,7 @@ static gint update_avgvar(gpointer data)
   return TRUE;
 }
 
+
 static gint update_avgfill(gpointer data)	
 {
   GtkWidget *label;
@@ -223,6 +226,7 @@ static gint update_avgfill(gpointer data)
   return TRUE;
 }
 
+
 static gint update_peakfreq(gpointer data)	
 {
   GtkWidget *label;
@@ -300,37 +304,6 @@ static gint update_cpu_usage(gpointer data)
 }
 
 
-
-
-static void spectrum_file_save(gchar *filename) 
-{
-  GError *error = NULL;
-  gboolean save_ok;
-
-  if (g_str_has_suffix(filename, ".jpg") || g_str_has_suffix(filename, ".JPG"))
-    save_ok = gdk_pixbuf_save (pixbuf, filename, "jpeg", &error, "quality", "100", NULL);
-  else
-    if (g_str_has_suffix(filename, ".png") || g_str_has_suffix(filename, ".PNG"))
-      save_ok = gdk_pixbuf_save (pixbuf, filename, "png", &error, NULL);
-    else
-      if (g_str_has_suffix(filename, ".bmp") || g_str_has_suffix(filename, ".BMP"))
-	save_ok = gdk_pixbuf_save (pixbuf, filename, "bmp", &error, NULL);
-
-  if (!save_ok) {
-    /* something went wrong, print error message and free memory */
-    g_warning("%s\n", error->message);
-    g_error_free(error);
-    gdk_pixbuf_unref(pixbuf);
-    //g_string_free(filename, TRUE);
-    //return FALSE;
-  }
-  /* everything went OK, free memory */
-  //g_string_free(filename, TRUE);
-  gdk_pixbuf_unref(pixbuf);
-  //return TRUE;
-}
-
-
 static void select_soundcard_source(GtkWidget * widget, gpointer data)
 {
   stop_reading_audio();
@@ -341,101 +314,12 @@ static void select_soundcard_source(GtkWidget * widget, gpointer data)
 }
 
 
-static void open_file_dialog(GtkWidget * widget, gpointer data)
-{
-  GtkWidget *dialog;
-  GtkFileFilter *filter;
-
-  dialog = gtk_file_chooser_dialog_new ("Open File", NULL,
-					GTK_FILE_CHOOSER_ACTION_OPEN, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
-  
-  filter = gtk_file_filter_new();
-  gtk_file_filter_set_name (filter, "Wav");
-  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
-  gtk_file_filter_add_pattern (filter, "*.[Ww][Aa][Vv]");
-
-  filter = gtk_file_filter_new();
-  gtk_file_filter_set_name (filter, "All files");
-  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
-  gtk_file_filter_add_pattern (filter, "*");
-
-  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
-    char *filename;
-    
-    filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
-    stop_reading_audio();
-    init_audio(filename);
-    start_reading_audio();
-    glfer.first_buffer = TRUE; /* need to reinitialize display autoscale */
-    g_free(filename);
-  }
-  
-  gtk_widget_destroy (dialog);
-}
-
-
-static void save_spect_dialog(GtkWidget * widget, gpointer data)
-{
-  GtkWidget *dialog;
-  GtkFileFilter *filter;
-
-  dialog = gtk_file_chooser_dialog_new ("Save File", NULL, 
-					GTK_FILE_CHOOSER_ACTION_SAVE, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT, NULL);
-
-  gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER(dialog), TRUE);
-
-  /*
-  filter = gtk_file_filter_new();
-  gtk_file_filter_set_name (filter, "Supported formats");
-  gtk_file_filter_add_pixbuf_formats(filter);
-  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(dialog), filter);
-  */
-
-  filter = gtk_file_filter_new();
-  gtk_file_filter_set_name (filter, "JPEG");
-  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
-  gtk_file_filter_add_pattern (filter, "*.[Jj][Pp][Gg]");
-
-  filter = gtk_file_filter_new();
-  gtk_file_filter_set_name (filter, "PNG");
-  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
-  gtk_file_filter_add_pattern (filter, "*.[Pp][Nn][Gg]");
-
-  filter = gtk_file_filter_new();
-  gtk_file_filter_set_name (filter, "BMP");
-  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
-  gtk_file_filter_add_pattern (filter, "*.[Bb][Mm][Pp]");
-
-  filter = gtk_file_filter_new();
-  gtk_file_filter_set_name (filter, "All files");
-  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
-  gtk_file_filter_add_pattern (filter, "*");
-
-  //if (user_edited_a_new_document) {
-  // gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), default_folder_for_saving);
-  //gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), "glfer.jpg");
-  //} else 
-  //  gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (dialog), filename_for_existing_document);
-  
-  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
-    char *filename;
-    
-    filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
-    spectrum_file_save(filename);
-    g_free (filename);
-  }
-
-  gtk_widget_destroy (dialog);
-}
-
-
 static gint delete_event(GtkWidget * widget, GdkEvent * event, gpointer data)
 {
   return FALSE;
 }
 
+
 /* copy spcol_px pixmap content onto spec_da on exposure */
 static gboolean cols_da_expose_event(GtkWidget * widget, GdkEventExpose * event, gpointer user_data)
 {
@@ -445,6 +329,7 @@ static gboolean cols_da_expose_event(GtkWidget * widget, GdkEventExpose * event,
   return FALSE;
 }
 
+
 static int spcols_da_configure_event(GtkWidget * widget, GdkEventConfigure * event, gpointer user_data)
 {
   if (spcols_px) {
@@ -459,6 +344,7 @@ static int spcols_da_configure_event(GtkWidget * widget, GdkEventConfigure * eve
   return TRUE;
 }
 
+
 /* copy spec_pixmap content onto spec_da on exposure */
 static gboolean spec_da_expose_event(GtkWidget * widget, GdkEventExpose * event, gpointer user_data)
 {
@@ -1441,6 +1327,7 @@ static void select_mode(GtkWidget * widget, gpointer data)
   change_params(mode_sel);
 }
 
+
 void save_full_pixmap(GtkWidget * widget, gpointer data)
 {
   pixbuf = gdk_pixbuf_get_from_drawable(NULL, pixmap, gdk_rgb_get_colormap(), 0, 0, 0, 0, pixmap_width, pixmap_height);
