@@ -1,6 +1,6 @@
 /* g_options.c
  * 
- * Copyright (C) 2001-2008 Claudio Girardi
+ * Copyright (C) 2001-2009 Claudio Girardi
  *           (C) 2006      Edouard Griffiths for modifications implementing
  *                         averaging mode
  * 
@@ -49,8 +49,7 @@ extern int num_fft_windows;
 
 static GtkWidget *spec_window = NULL, *qrss_window = NULL, *tx_test_window = NULL, *port_window = NULL, *audio_window = NULL;
 static GtkWidget *sn_bu, *be_keyup_bu, *be_keydown_bu, *qrss_bu, *dfcw_bu, *serial_bu, *parallel_bu, *hendrix_bu, *autoscale_bu;
-static GtkWidget *offset_en, *data_block_size_en, *data_blocks_overlap_en, *display_update_en, *limiter_a_en, *mtm_w_en, *mtm_k_en, *hparma_t_en, *hparma_p_e_en, *lmp_av_en, *sample_rate_en, *dot_time_en, *wpm_en, *lin_scale_bu, *log_scale_bu, *ptt_delay_en, *sidetone_fr_en, *dfcw_dot_fr_en, *dfcw_dash_fr_en, *be_pause_en, *level_en, *lin_scale_bu, *lin_scale_max0_bu, *log_scale_bu, *log_scale_max0_bu, *avg_sumavg_bu, *avg_plain_bu, *avg_sumextreme_bu, *noavg_bu, *max_level_en, *min_level_en, *avgsamples_en, *minavgband_en, *maxavgband_en, *audio_device_en, *avgtime_la, *avgintdb_la, *bin_size_la;  ;
-static GtkWidget *serial_dev_cb, *parallel_dev_cb;
+static GtkWidget *offset_en, *data_block_size_en, *data_blocks_overlap_en, *display_update_en, *limiter_a_en, *mtm_w_en, *mtm_k_en, *hparma_t_en, *hparma_p_e_en, *lmp_av_en, *sample_rate_en, *dot_time_en, *control_port_en, *wpm_en, *lin_scale_bu, *log_scale_bu, *ptt_delay_en, *sidetone_fr_en, *dfcw_dot_fr_en, *dfcw_dash_fr_en, *be_pause_en, *level_en, *lin_scale_bu, *lin_scale_max0_bu, *log_scale_bu, *log_scale_max0_bu, *avg_sumavg_bu, *avg_plain_bu, *avg_sumextreme_bu, *noavg_bu, *max_level_en, *min_level_en, *avgsamples_en, *minavgband_en, *maxavgband_en, *audio_device_en, *avgtime_la, *avgintdb_la, *bin_size_la;  ;
 
 
 typedef struct _palette_t palette_t;
@@ -1266,17 +1265,6 @@ void qrss_settings_dialog(GtkWidget * widget, gpointer data)
 }
 
 
-static void devtype_clicked(GtkWidget * widget, gpointer data)
-{
-  GtkWidget *combo = data;
-
-  if (GTK_TOGGLE_BUTTON(widget)->active == TRUE)
-    gtk_widget_set_sensitive(combo, TRUE);
-  else
-    gtk_widget_set_sensitive(combo, FALSE);
-}
-
-
 static void port_change_device(GtkWidget * widget, gpointer data)
 {
   int dev_status = -1;		/* avoid warning about uninitialized variable */
@@ -1298,12 +1286,12 @@ static void port_change_device(GtkWidget * widget, gpointer data)
   if (GTK_TOGGLE_BUTTON(serial_bu)->active) {	/* serial device selected */
     opt.device_type = DEV_SERIAL;
     FREE_MAYBE(opt.ctrl_device);
-    opt.ctrl_device = gtk_editable_get_chars(GTK_EDITABLE(GTK_COMBO(serial_dev_cb)->entry), 0, -1);
+    opt.ctrl_device = gtk_editable_get_chars(GTK_EDITABLE(control_port_en), 0, -1);
     dev_status = open_serial_port(opt.ctrl_device);
   } else if (GTK_TOGGLE_BUTTON(parallel_bu)->active) {
     opt.device_type = DEV_PARALLEL;
     FREE_MAYBE(opt.ctrl_device);
-    opt.ctrl_device = gtk_editable_get_chars(GTK_EDITABLE(GTK_COMBO(parallel_dev_cb)->entry), 0, -1);
+    opt.ctrl_device = gtk_editable_get_chars(GTK_EDITABLE(control_port_en), 0, -1);
     dev_status = open_parport(opt.ctrl_device);
   } else {
     g_assert_not_reached();
@@ -1329,22 +1317,13 @@ static void port_change_device(GtkWidget * widget, gpointer data)
 
 static void port_prefs_to_widgets(void)
 {
-  if (glfer.init_done == FALSE) {
-    /* first initialisation, select serial device type */
-    gtk_widget_set_sensitive(parallel_dev_cb, FALSE);
+  gtk_entry_set_text(GTK_ENTRY(control_port_en), opt.ctrl_device);
+  if (opt.device_type == DEV_SERIAL) {
     gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(serial_bu), TRUE);
+  } else if (opt.device_type == DEV_PARALLEL) {
+    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(parallel_bu), TRUE);
   } else {
-    if (opt.device_type == DEV_SERIAL) {
-      gtk_widget_set_sensitive(parallel_dev_cb, FALSE);
-      gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(serial_bu), TRUE);
-      gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(serial_dev_cb)->entry), opt.ctrl_device);
-    } else if (opt.device_type == DEV_PARALLEL) {
-      gtk_widget_set_sensitive(serial_dev_cb, FALSE);
-      gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(parallel_bu), TRUE);
-      gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(parallel_dev_cb)->entry), opt.ctrl_device);
-    } else {
-      g_assert_not_reached();
-    }
+    g_assert_not_reached();
   }
 }
 
@@ -1354,11 +1333,7 @@ static void port_widgets_to_prefs(GtkWidget * widget, gpointer data)
   GtkWidget *dialog, *ok_bu, *cancel_bu, *label;
   char *selected_device = NULL;
 
-  if (GTK_TOGGLE_BUTTON(serial_bu)->active) {	/* serial device selected */
-    selected_device = gtk_editable_get_chars(GTK_EDITABLE(GTK_COMBO(serial_dev_cb)->entry), 0, -1);
-  } else {
-    selected_device = gtk_editable_get_chars(GTK_EDITABLE(GTK_COMBO(parallel_dev_cb)->entry), 0, -1);
-  }
+  selected_device = gtk_editable_get_chars(GTK_EDITABLE(control_port_en), 0, -1);
 
   if ((glfer.init_done == FALSE) || strcmp(opt.ctrl_device, selected_device)) {
     /* first initialisation or different device selected */
@@ -1430,56 +1405,30 @@ void port_settings_dialog(GtkWidget * widget, gpointer data)
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(port_window)->vbox), tmp_hb, FALSE, FALSE, 10);
   gtk_widget_show(tmp_hb);
 
-  /* serial devices frame */
-  pa_fr = gtk_frame_new("Serial devices");
+  /* control devices frame */
+  pa_fr = gtk_frame_new("Control device");
   gtk_box_pack_start(GTK_BOX(tmp_hb), pa_fr, FALSE, FALSE, 10);
   gtk_widget_show(pa_fr);
-  /* serial devices vbox */
+  /* control devices vbox */
   tmp_vb = gtk_vbox_new(FALSE, 5);
   gtk_container_add(GTK_CONTAINER(pa_fr), tmp_vb);
   gtk_widget_show(tmp_vb);
 
-  /* serial devices entry */
-  serial_dev_it = g_list_append(serial_dev_it, "ttyS0");
-  serial_dev_it = g_list_append(serial_dev_it, "ttyS1");
-  serial_dev_it = g_list_append(serial_dev_it, "ttyS2");
-  serial_dev_it = g_list_append(serial_dev_it, "ttyS3");
-  serial_dev_cb = gtk_combo_new();
-  gtk_tooltips_set_tip(glfer.tt, serial_dev_cb, "Serial port TX control devices", NULL);
-  gtk_combo_set_popdown_strings(GTK_COMBO(serial_dev_cb), serial_dev_it);
-  gtk_box_pack_start(GTK_BOX(tmp_vb), serial_dev_cb, TRUE, TRUE, 5);
-  gtk_widget_show(serial_dev_cb);
+  /* control port entry */
+  compound_entry("/dev/", &control_port_en, tmp_vb);
+  gtk_tooltips_set_tip(glfer.tt, control_port_en, "Control port name (e.g. ttyS0 for serial, lp0 for parallel)", NULL);
+
   /* device type radio button */
-  serial_bu = gtk_radio_button_new_with_label(NULL, "Enable serial");
+  serial_bu = gtk_radio_button_new_with_label(NULL, "Serial port");
   gtk_tooltips_set_tip(glfer.tt, serial_bu, "Enable serial control port", NULL);
   devtype_gr = gtk_radio_button_group(GTK_RADIO_BUTTON(serial_bu));
-  g_signal_connect(G_OBJECT(serial_bu), "clicked", G_CALLBACK(devtype_clicked), serial_dev_cb);
   gtk_box_pack_start(GTK_BOX(tmp_vb), serial_bu, TRUE, TRUE, 5);
   gtk_widget_show(serial_bu);
 
-  /* parallel devices frame */
-  pa_fr = gtk_frame_new("Parallel devices");
-  gtk_box_pack_start(GTK_BOX(tmp_hb), pa_fr, FALSE, FALSE, 10);
-  gtk_widget_show(pa_fr);
-  /* parallel devices vbox */
-  tmp_vb = gtk_vbox_new(FALSE, 5);
-  gtk_container_add(GTK_CONTAINER(pa_fr), tmp_vb);
-  gtk_widget_show(tmp_vb);
-
-  /* parallel devices entry */
-  parallel_dev_it = g_list_append(parallel_dev_it, "lp0");
-  parallel_dev_it = g_list_append(parallel_dev_it, "lp1");
-  parallel_dev_cb = gtk_combo_new();
-  gtk_tooltips_set_tip(glfer.tt, parallel_dev_cb, "Parallel port TX control devices", NULL);
-  gtk_combo_set_popdown_strings(GTK_COMBO(parallel_dev_cb), parallel_dev_it);
-  gtk_box_pack_start(GTK_BOX(tmp_vb), parallel_dev_cb, TRUE, TRUE, 5);
-  gtk_widget_show(parallel_dev_cb);
-
   /* device type radio button */
-  parallel_bu = gtk_radio_button_new_with_label(devtype_gr, "Enable parallel");
+  parallel_bu = gtk_radio_button_new_with_label(devtype_gr, "Parallel port");
   gtk_tooltips_set_tip(glfer.tt, parallel_bu, "Enable parallel control port", NULL);
   devtype_gr = gtk_radio_button_group(GTK_RADIO_BUTTON(parallel_bu));
-  g_signal_connect(G_OBJECT(parallel_bu), "clicked", G_CALLBACK(devtype_clicked), parallel_dev_cb);
   gtk_box_pack_start(GTK_BOX(tmp_vb), parallel_bu, TRUE, TRUE, 5);
   gtk_widget_show(parallel_bu);
 
