@@ -1,6 +1,6 @@
 /* g_options.h
  * 
- * Copyright (C) 2001 Claudio Girardi
+ * Copyright (C) 2001-2007 Claudio Girardi
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,8 +13,8 @@
  * General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA, 02111-1307, USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
 #ifndef _G_OPTIONS_H_
@@ -28,4 +28,6 @@ void qrss_settings_dialog(GtkWidget * widget, gpointer data);
 
 void port_settings_dialog(GtkWidget * widget, gpointer data);
 
+void audio_settings_dialog(GtkWidget * widget, gpointer data);
+
 #endif /* _G_OPTIONS_H_ */
