@@ -13,8 +13,8 @@
  * General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA, 02111-1307, USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
 #include <stdio.h>
@@ -172,9 +172,9 @@ static void filter_entry_text(GtkEntry * entry, const gchar * text, gint length,
   }
 
   if (count > 0) {
-    gtk_signal_handler_block_by_func(GTK_OBJECT(editable), GTK_SIGNAL_FUNC(filter_entry_text), data);
+    gtk_signal_handler_block_by_func(GTK_OBJECT(editable), G_CALLBACK(filter_entry_text), data);
     gtk_editable_insert_text(editable, result, count, position);
-    gtk_signal_handler_unblock_by_func(GTK_OBJECT(editable), GTK_SIGNAL_FUNC(filter_entry_text), data);
+    gtk_signal_handler_unblock_by_func(GTK_OBJECT(editable), G_CALLBACK(filter_entry_text), data);
   }
   gtk_signal_emit_stop_by_name(GTK_OBJECT(editable), "insert_text");
 
@@ -215,7 +215,7 @@ void create_txmsg_window(void)
   if (!window) {
     window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
-    gtk_signal_connect(GTK_OBJECT(window), "destroy", GTK_SIGNAL_FUNC(gtk_widget_destroyed), &window);
+    g_signal_connect(G_OBJECT(window), "destroy", G_CALLBACK(gtk_widget_destroyed), &window);
 
     gtk_window_set_title(GTK_WINDOW(window), "TX Message");
     gtk_container_border_width(GTK_CONTAINER(window), 0);
@@ -235,11 +235,11 @@ void create_txmsg_window(void)
     gtk_widget_set_usize(entry, 200, -1);
     gtk_box_pack_end(GTK_BOX(temp_hb), entry, TRUE, TRUE, 5);
     /* filter the input in the entry (from the GTK+ FAQ) */
-    gtk_signal_connect(GTK_OBJECT(entry), "insert_text", GTK_SIGNAL_FUNC(filter_entry_text), NULL);
+    g_signal_connect(G_OBJECT(entry), "insert_text", G_CALLBACK(filter_entry_text), NULL);
     /* update timers with message */
-    gtk_signal_connect(GTK_OBJECT(entry), "changed", GTK_SIGNAL_FUNC(entry_changed), NULL);
+    g_signal_connect(G_OBJECT(entry), "changed", G_CALLBACK(entry_changed), NULL);
     /* pressing ENTER is the same as clicking on the Start button */
-    gtk_signal_connect(GTK_OBJECT(entry), "activate", GTK_SIGNAL_FUNC(start_message), GTK_OBJECT(entry));
+    g_signal_connect(G_OBJECT(entry), "activate", G_CALLBACK(start_message), GTK_OBJECT(entry));
     gtk_widget_show(entry);
     /* entry description */
     temp_la = gtk_label_new("Text:");
@@ -275,7 +275,7 @@ void create_txmsg_window(void)
     be_bu = gtk_check_button_new_with_label("Beacon mode");
     gtk_tooltips_set_tip(glfer.tt, be_bu, "Enable/disable beacon mode (repeated message)", NULL);
     gtk_box_pack_start(GTK_BOX(vbox), be_bu, FALSE, FALSE, 0);
-    gtk_signal_connect(GTK_OBJECT(be_bu), "clicked", GTK_SIGNAL_FUNC(enable_beacon_mode), NULL);
+    g_signal_connect(G_OBJECT(be_bu), "clicked", G_CALLBACK(enable_beacon_mode), NULL);
     /* if beacon mode  enabled activate the toggle button */
     if (opt.beacon_mode == TRUE) {
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(be_bu), TRUE);
@@ -294,8 +294,8 @@ void create_txmsg_window(void)
     gtk_box_pack_end(GTK_BOX(temp_hb), cancel_button, TRUE, TRUE, 0);
 
     /* pressing Cancel is the same as pressing Stop end closing the window */
-    gtk_signal_connect(GTK_OBJECT(cancel_button), "clicked", GTK_SIGNAL_FUNC(stop_message), GTK_OBJECT(entry));
-    gtk_signal_connect_object(GTK_OBJECT(cancel_button), "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(window));
+    g_signal_connect(G_OBJECT(cancel_button), "clicked", G_CALLBACK(stop_message), GTK_OBJECT(entry));
+    g_signal_connect_swapped(G_OBJECT(cancel_button), "clicked", G_CALLBACK(gtk_widget_destroy), GTK_OBJECT(window));
     gtk_widget_show(cancel_button);
 
     /* transmission start button */
@@ -303,7 +303,7 @@ void create_txmsg_window(void)
     gtk_tooltips_set_tip(glfer.tt, start_button, "Start message transmission", NULL);
     gtk_box_pack_start(GTK_BOX(temp_hb), start_button, TRUE, TRUE, 0);
 
-    gtk_signal_connect(GTK_OBJECT(start_button), "clicked", GTK_SIGNAL_FUNC(start_message), GTK_OBJECT(entry));
+    g_signal_connect(G_OBJECT(start_button), "clicked", G_CALLBACK(start_message), GTK_OBJECT(entry));
     gtk_widget_show(start_button);
 
     /* transmission stop button */
@@ -311,7 +311,7 @@ void create_txmsg_window(void)
     gtk_tooltips_set_tip(glfer.tt, stop_button, "Stop message transmission", NULL);
     gtk_box_pack_start(GTK_BOX(temp_hb), stop_button, TRUE, TRUE, 0);
 
-    gtk_signal_connect(GTK_OBJECT(stop_button), "clicked", GTK_SIGNAL_FUNC(stop_message), GTK_OBJECT(entry));
+    g_signal_connect(G_OBJECT(stop_button), "clicked", G_CALLBACK(stop_message), GTK_OBJECT(entry));
     gtk_widget_show(stop_button);
 
     gtk_widget_show(temp_hb);
