@@ -13,8 +13,8 @@
  * General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA, 02111-1307, USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
 
@@ -39,7 +39,7 @@
 #endif
 
 #include <signal.h>
-#include <linux/kd.h>		/* for KIOCSOUND */
+#include <sys/kd.h>		/* for KIOCSOUND */
 #include <fcntl.h>		/* file control definitions */
 #include <sys/ioctl.h>
 /* #include <asm/io.h>  *//* for inb() and outb() in libc5 only ? */
