@@ -1,6 +1,8 @@
 /* rcfile.c
  * 
  * Copyright (C) 2001-2002 Claudio Girardi
+ *           (C) 2006      Edouard Griffiths for modifications implementing
+ *                         averaging mode
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,8 +15,8 @@
  * General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA, 02111-1307, USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
 #include <stdio.h>
@@ -43,7 +45,7 @@ char *rc_filename = NULL;
 int parse_rcfile(void)
 {
   char *env_home;
-  char *rc_name = PACKAGE "rc";
+  char *rc_name = PACKAGE_NAME "rc";
   char *filename = NULL;
   int result;
 
@@ -112,21 +114,13 @@ int rc_file_parse(const char *filename)
       if (skip_equals(&i)) {
 	opt.scale_type = atoi(i);
       }
-    } else if (!strncasecmp(i, "fft_n", 5)) {
+    } else if (!strncasecmp(i, "data_block_size", 15)) {
       if (skip_equals(&i)) {
-	opt.fft_n = atoi(i);
+	opt.data_block_size = atoi(i);
       }
-    } else if (!strncasecmp(i, "fft_overlap", 11)) {
+    } else if (!strncasecmp(i, "data_blocks_overlap", 19)) {
       if (skip_equals(&i)) {
-	opt.fft_overlap = atof(i);
-      }
-    } else if (!strncasecmp(i, "mtm_n", 5)) {
-      if (skip_equals(&i)) {
-	opt.mtm_n = atoi(i);
-      }
-    } else if (!strncasecmp(i, "mtm_overlap", 11)) {
-      if (skip_equals(&i)) {
-	opt.mtm_overlap = atof(i);
+	opt.data_blocks_overlap = atof(i);
       }
     } else if (!strncasecmp(i, "mtm_w", 5)) {
       if (skip_equals(&i)) {
@@ -136,14 +130,6 @@ int rc_file_parse(const char *filename)
       if (skip_equals(&i)) {
 	opt.mtm_k = atoi(i);
       }
-    } else if (!strncasecmp(i, "hparma_n", 8)) {
-      if (skip_equals(&i)) {
-	opt.hparma_n = atoi(i);
-      }
-    } else if (!strncasecmp(i, "hparma_overlap", 14)) {
-      if (skip_equals(&i)) {
-	opt.hparma_overlap = atof(i);
-      }
     } else if (!strncasecmp(i, "hparma_t", 8)) {
       if (skip_equals(&i)) {
 	opt.hparma_t = atof(i);
@@ -154,7 +140,7 @@ int rc_file_parse(const char *filename)
       }
     } else if (!strncasecmp(i, "window_type", 11)) {
       if (skip_equals(&i)) {
-	opt.window_type = atof(i);
+	opt.window_type = atoi(i);
       }
     } else if (!strncasecmp(i, "sample_rate", 11)) {
       if (skip_equals(&i)) {
@@ -263,6 +249,38 @@ int rc_file_parse(const char *filename)
       if (skip_equals(&i)) {
 	opt.thr_level = atof(i);
       }
+    } else if (!strncasecmp(i, "autoscale", 9)) {         
+      if (skip_equals(&i)) {
+      	opt.autoscale = atoi(i);
+    }
+    } else if (!strncasecmp(i, "max_level_db", 12)) {     
+      if (skip_equals(&i)) {
+      	opt.max_level_db = atof(i);
+    }
+    } else if (!strncasecmp(i, "min_level_db", 12)) {     
+      if (skip_equals(&i)) {
+      	opt.min_level_db = atof(i);
+    }
+    } else if (!strncasecmp(i, "palette", 7)) {           
+      if (skip_equals(&i)) {
+      	opt.palette = atoi(i);
+    }
+    } else if (!strncasecmp(i, "avg_mode", 8)) {          
+      if (skip_equals(&i)) {
+      	opt.averaging = atoi(i);
+    }
+    } else if (!strncasecmp(i, "avg_nsamples", 12)) {     
+      if (skip_equals(&i)) {
+      	opt.avgsamples = atoi(i);
+    }
+    } else if (!strncasecmp(i, "avg_min_avgband", 15)) {  
+      if (skip_equals(&i)) {
+      	opt.min_avgband = atof(i);
+    }
+    } else if (!strncasecmp(i, "avg_max_avgband", 15)) {  
+      if (skip_equals(&i)) {
+      	opt.max_avgband = atof(i);
+    }
 
     } else
       fprintf(stderr, "error in rcfile %s: %s\n", filename, buf);
@@ -288,11 +306,7 @@ int rc_file_write(void)
     return (-1);
 
   /* write header */
-  fprintf(fp, "# This is the startup file for " PACKAGE
-#ifdef VERSION
-	  "-" VERSION
-#endif /* #ifdef VERSION */
-	  "\n");
+  fprintf(fp, "# This is the startup file for " PACKAGE_STRING "\n");
   fprintf(fp, "# automatically generated on %s", ctime(&date));
   fprintf(fp, "\n");
   fprintf(fp, "# Lines starting with \'#\' are ignored\n");
@@ -300,16 +314,12 @@ int rc_file_write(void)
   fprintf(fp, "mode = %i\n", opt.mode);
   fprintf(fp, "scale_type = %i\n", opt.scale_type);
 
-  fprintf(fp, "fft_n = %i\n", opt.fft_n);
-  fprintf(fp, "fft_overlap = %f\n", opt.fft_overlap);
+  fprintf(fp, "data_block_size = %i\n", opt.data_block_size);
+  fprintf(fp, "data_blocks_overlap = %f\n", opt.data_blocks_overlap);
 
-  fprintf(fp, "mtm_n = %i\n", opt.mtm_n);
-  fprintf(fp, "mtm_overlap = %f\n", opt.mtm_overlap);
   fprintf(fp, "mtm_w = %f\n", opt.mtm_w);
-  fprintf(fp, "mtm_kw = %i\n", opt.mtm_k);
+  fprintf(fp, "mtm_k = %i\n", opt.mtm_k);
 
-  fprintf(fp, "hparma_n = %i\n", opt.hparma_n);
-  fprintf(fp, "hparma_overlap = %f\n", opt.hparma_overlap);
   fprintf(fp, "hparma_t = %i\n", opt.hparma_t);
   fprintf(fp, "hparma_p_e = %i\n", opt.hparma_p_e);
 
@@ -333,6 +343,16 @@ int rc_file_write(void)
   fprintf(fp, "device_type = %s\n", opt.device_type == DEV_SERIAL ? "DEV_SERIAL" : "DEV_PARALLEL");
   fprintf(fp, "audio_device = %s\n", opt.audio_device);
   fprintf(fp, "thr_level = %f\n", opt.thr_level);
+  fprintf(fp, "autoscale = %i\n", opt.autoscale);             
+  fprintf(fp, "max_level_db = %f\n", opt.max_level_db);       
+  fprintf(fp, "min_level_db = %f\n", opt.min_level_db);       
+  fprintf(fp, "palette = %i\n", opt.palette);                 
+   
+  fprintf(fp, "avg_mode = %i\n", opt.averaging);              
+  fprintf(fp, "avg_nsamples = %i\n", opt.avgsamples);         
+  fprintf(fp, "avg_min_avgband = %f\n", opt.min_avgband);     
+  fprintf(fp, "avg_max_avgband = %f\n", opt.max_avgband);     
+  
   fclose(fp);
 
   return (0);
